@@ -1,4 +1,4 @@
 package static
 
 // PluginConf holds the plugin configuration.
-type PluginConf map[string]interface{}
+type PluginConf map[string]any
