@@ -7,10 +7,10 @@ import (
 
 func NewGoKitWrapper(logger zerolog.Logger) kitlog.LoggerFunc {
 	if logger.GetLevel() > zerolog.DebugLevel {
-		return func(args ...interface{}) error { return nil }
+		return func(args ...any) error { return nil }
 	}
 
-	return func(args ...interface{}) error {
+	return func(args ...any) error {
 		logger.Debug().CallerSkipFrame(2).MsgFunc(msgFunc(args...))
 		return nil
 	}
