@@ -248,6 +248,11 @@ func (p *Provider) Provide(configurationChan chan<- dynamic.Message, pool *safe.
 	return nil
 }
 
+// Namespace returns the namespace of the ConsulCatalog provider.
+func (p *Provider) Namespace() string {
+	return p.namespace
+}
+
 func (p *Provider) loadConfiguration(ctx context.Context, certInfo *connectCert, configurationChan chan<- dynamic.Message) error {
 	data, err := p.getConsulServicesData(ctx)
 	if err != nil {
@@ -388,12 +393,12 @@ func (p *Provider) fetchService(ctx context.Context, name string, connectEnabled
 // watchServices watches for update events of the services list and statuses,
 // and transmits them to the caller through the p.watchServicesChan.
 func (p *Provider) watchServices(ctx context.Context) error {
-	servicesWatcher, err := watch.Parse(map[string]interface{}{"type": "services"})
+	servicesWatcher, err := watch.Parse(map[string]any{"type": "services"})
 	if err != nil {
 		return fmt.Errorf("failed to create services watcher plan: %w", err)
 	}
 
-	servicesWatcher.HybridHandler = func(_ watch.BlockingParamVal, _ interface{}) {
+	servicesWatcher.HybridHandler = func(_ watch.BlockingParamVal, _ any) {
 		select {
 		case <-ctx.Done():
 		case p.watchServicesChan <- struct{}{}:
@@ -402,12 +407,12 @@ func (p *Provider) watchServices(ctx context.Context) error {
 		}
 	}
 
-	checksWatcher, err := watch.Parse(map[string]interface{}{"type": "checks"})
+	checksWatcher, err := watch.Parse(map[string]any{"type": "checks"})
 	if err != nil {
 		return fmt.Errorf("failed to create checks watcher plan: %w", err)
 	}
 
-	checksWatcher.HybridHandler = func(_ watch.BlockingParamVal, _ interface{}) {
+	checksWatcher.HybridHandler = func(_ watch.BlockingParamVal, _ any) {
 		select {
 		case <-ctx.Done():
 		case p.watchServicesChan <- struct{}{}:
@@ -447,66 +452,11 @@ func (p *Provider) watchServices(ctx context.Context) error {
 	}
 }
 
-func rootsWatchHandler(ctx context.Context, dest chan<- []string) func(watch.BlockingParamVal, interface{}) {
-	return func(_ watch.BlockingParamVal, raw interface{}) {
-		if raw == nil {
-			log.Ctx(ctx).Error().Msg("Root certificate watcher called with nil")
-			return
-		}
-
-		v, ok := raw.(*api.CARootList)
-		if !ok || v == nil {
-			log.Ctx(ctx).Error().Msg("Invalid result for root certificate watcher")
-			return
-		}
-
-		roots := make([]string, 0, len(v.Roots))
-		for _, root := range v.Roots {
-			roots = append(roots, root.RootCertPEM)
-		}
-
-		select {
-		case <-ctx.Done():
-		case dest <- roots:
-		}
-	}
-}
-
-type keyPair struct {
-	cert string
-	key  string
-}
-
-func leafWatcherHandler(ctx context.Context, dest chan<- keyPair) func(watch.BlockingParamVal, interface{}) {
-	return func(_ watch.BlockingParamVal, raw interface{}) {
-		if raw == nil {
-			log.Ctx(ctx).Error().Msg("Leaf certificate watcher called with nil")
-			return
-		}
-
-		v, ok := raw.(*api.LeafCert)
-		if !ok || v == nil {
-			log.Ctx(ctx).Error().Msg("Invalid result for leaf certificate watcher")
-			return
-		}
-
-		kp := keyPair{
-			cert: v.CertPEM,
-			key:  v.PrivateKeyPEM,
-		}
-
-		select {
-		case <-ctx.Done():
-		case dest <- kp:
-		}
-	}
-}
-
 // watchConnectTLS watches for updates of the root certificate or the leaf
 // certificate, and transmits them to the caller via p.certChan.
 func (p *Provider) watchConnectTLS(ctx context.Context) error {
 	leafChan := make(chan keyPair)
-	leafWatcher, err := watch.Parse(map[string]interface{}{
+	leafWatcher, err := watch.Parse(map[string]any{
 		"type":    "connect_leaf",
 		"service": p.ServiceName,
 	})
@@ -515,8 +465,8 @@ func (p *Provider) watchConnectTLS(ctx context.Context) error {
 	}
 	leafWatcher.HybridHandler = leafWatcherHandler(ctx, leafChan)
 
-	rootsChan := make(chan []string)
-	rootsWatcher, err := watch.Parse(map[string]interface{}{
+	rootsChan := make(chan caRootList)
+	rootsWatcher, err := watch.Parse(map[string]any{
 		"type": "connect_roots",
 	})
 	if err != nil {
@@ -547,9 +497,9 @@ func (p *Provider) watchConnectTLS(ctx context.Context) error {
 	}()
 
 	var (
-		certInfo  *connectCert
-		leafCerts keyPair
-		rootCerts []string
+		certInfo *connectCert
+		leafCert keyPair
+		caRoots  caRootList
 	)
 
 	for {
@@ -560,13 +510,14 @@ func (p *Provider) watchConnectTLS(ctx context.Context) error {
 		case err := <-errChan:
 			return fmt.Errorf("leaf or roots watcher terminated: %w", err)
 
-		case rootCerts = <-rootsChan:
-		case leafCerts = <-leafChan:
+		case caRoots = <-rootsChan:
+		case leafCert = <-leafChan:
 		}
 
 		newCertInfo := &connectCert{
-			root: rootCerts,
-			leaf: leafCerts,
+			trustDomain: caRoots.trustDomain,
+			root:        caRoots.roots,
+			leaf:        leafCert,
 		}
 		if newCertInfo.isReady() && !newCertInfo.equals(certInfo) {
 			log.Ctx(ctx).Debug().Msgf("Updating connect certs for service %s", p.ServiceName)
@@ -596,6 +547,66 @@ func (p *Provider) includesHealthStatus(status string) bool {
 	return false
 }
 
+type caRootList struct {
+	trustDomain string
+	roots       []string
+}
+
+func rootsWatchHandler(ctx context.Context, dest chan<- caRootList) func(watch.BlockingParamVal, any) {
+	return func(_ watch.BlockingParamVal, raw any) {
+		if raw == nil {
+			log.Ctx(ctx).Error().Msg("Root certificate watcher called with nil")
+			return
+		}
+
+		v, ok := raw.(*api.CARootList)
+		if !ok || v == nil {
+			log.Ctx(ctx).Error().Msg("Invalid result for root certificate watcher")
+			return
+		}
+
+		roots := make([]string, 0, len(v.Roots))
+		for _, root := range v.Roots {
+			roots = append(roots, root.RootCertPEM)
+		}
+
+		select {
+		case <-ctx.Done():
+		case dest <- caRootList{trustDomain: v.TrustDomain, roots: roots}:
+		}
+	}
+}
+
+type keyPair struct {
+	cert string
+	key  string
+}
+
+func leafWatcherHandler(ctx context.Context, dest chan<- keyPair) func(watch.BlockingParamVal, any) {
+	return func(_ watch.BlockingParamVal, raw any) {
+		if raw == nil {
+			log.Ctx(ctx).Error().Msg("Leaf certificate watcher called with nil")
+			return
+		}
+
+		v, ok := raw.(*api.LeafCert)
+		if !ok || v == nil {
+			log.Ctx(ctx).Error().Msg("Invalid result for leaf certificate watcher")
+			return
+		}
+
+		kp := keyPair{
+			cert: v.CertPEM,
+			key:  v.PrivateKeyPEM,
+		}
+
+		select {
+		case <-ctx.Done():
+		case dest <- kp:
+		}
+	}
+}
+
 func createClient(namespace string, endpoint *EndpointConfig) (*api.Client, error) {
 	config := api.Config{
 		Address:    endpoint.Address,
@@ -647,8 +658,3 @@ func repeatSend(ctx context.Context, interval time.Duration, c chan<- struct{})
 		}
 	}
 }
-
-// Namespace returns the namespace of the ConsulCatalog provider.
-func (p *Provider) Namespace() string {
-	return p.namespace
-}
