@@ -7,38 +7,38 @@ import (
 
 // ResourceEventHandler handles Add, Update or Delete Events for resources.
 type ResourceEventHandler struct {
-	Ev chan<- interface{}
+	Ev chan<- any
 }
 
 // OnAdd is called on Add Events.
-func (reh *ResourceEventHandler) OnAdd(obj interface{}, _ bool) {
+func (reh *ResourceEventHandler) OnAdd(obj any, _ bool) {
 	eventHandlerFunc(reh.Ev, obj)
 }
 
 // OnUpdate is called on Update Events.
 // Ignores useless changes.
-func (reh *ResourceEventHandler) OnUpdate(oldObj, newObj interface{}) {
+func (reh *ResourceEventHandler) OnUpdate(oldObj, newObj any) {
 	if objChanged(oldObj, newObj) {
 		eventHandlerFunc(reh.Ev, newObj)
 	}
 }
 
 // OnDelete is called on Delete Events.
-func (reh *ResourceEventHandler) OnDelete(obj interface{}) {
+func (reh *ResourceEventHandler) OnDelete(obj any) {
 	eventHandlerFunc(reh.Ev, obj)
 }
 
 // eventHandlerFunc will pass the obj on to the events channel or drop it.
 // This is so passing the events along won't block in the case of high volume.
 // The events are only used for signaling anyway so dropping a few is ok.
-func eventHandlerFunc(events chan<- interface{}, obj interface{}) {
+func eventHandlerFunc(events chan<- any, obj any) {
 	select {
 	case events <- obj:
 	default:
 	}
 }
 
-func objChanged(oldObj, newObj interface{}) bool {
+func objChanged(oldObj, newObj any) bool {
 	if oldObj == nil || newObj == nil {
 		return true
 	}
