@@ -50,16 +50,14 @@ func (eps UDPEntryPoints) Stop() {
 	var wg sync.WaitGroup
 
 	for epn, ep := range eps {
-		wg.Add(1)
-
-		go func(entryPointName string, entryPoint *UDPEntryPoint) {
+		wg.Go(func() {
 			defer wg.Done()
 
-			logger := log.With().Str(logs.EntryPointName, entryPointName).Logger()
-			entryPoint.Shutdown(logger.WithContext(context.Background()))
+			logger := log.With().Str(logs.EntryPointName, epn).Logger()
+			ep.Shutdown(logger.WithContext(context.Background()))
 
 			logger.Debug().Msg("Entry point closed")
-		}(epn, ep)
+		})
 	}
 
 	wg.Wait()
