@@ -16,6 +16,7 @@ var errNoAvailableServer = errors.New("no available server")
 
 type namedHandler struct {
 	http.Handler
+
 	name     string
 	weight   float64
 	deadline float64
@@ -78,7 +79,7 @@ func (b *Balancer) Swap(i, j int) {
 }
 
 // Push implements heap.Interface for pushing an item into the heap.
-func (b *Balancer) Push(x interface{}) {
+func (b *Balancer) Push(x any) {
 	h, ok := x.(*namedHandler)
 	if !ok {
 		return
@@ -89,7 +90,7 @@ func (b *Balancer) Push(x interface{}) {
 
 // Pop implements heap.Interface for popping an item from the heap.
 // It panics if b.Len() < 1.
-func (b *Balancer) Pop() interface{} {
+func (b *Balancer) Pop() any {
 	h := b.handlers[len(b.handlers)-1]
 	b.handlers = b.handlers[0 : len(b.handlers)-1]
 	return h
@@ -147,36 +148,6 @@ func (b *Balancer) RegisterStatusUpdater(fn func(up bool)) error {
 	return nil
 }
 
-func (b *Balancer) nextServer() (*namedHandler, error) {
-	b.handlersMu.Lock()
-	defer b.handlersMu.Unlock()
-
-	if len(b.handlers) == 0 || len(b.status) == 0 || len(b.fenced) == len(b.handlers) {
-		return nil, errNoAvailableServer
-	}
-
-	var handler *namedHandler
-	for {
-		// Pick handler with closest deadline.
-		handler = heap.Pop(b).(*namedHandler)
-
-		// curDeadline should be handler's deadline so that new added entry would have a fair competition environment with the old ones.
-		b.curDeadline = handler.deadline
-		handler.deadline += 1 / handler.weight
-
-		heap.Push(b, handler)
-		if _, ok := b.status[handler.name]; ok {
-			if _, ok := b.fenced[handler.name]; !ok {
-				// do not select a fenced handler.
-				break
-			}
-		}
-	}
-
-	log.Debug().Msgf("Service selected by WRR: %s", handler.name)
-	return handler, nil
-}
-
 func (b *Balancer) ServeHTTP(rw http.ResponseWriter, req *http.Request) {
 	if b.sticky != nil {
 		h, rewrite, err := b.sticky.StickyHandler(req)
@@ -250,3 +221,33 @@ func (b *Balancer) Add(name string, handler http.Handler, weight *int, fenced bo
 		b.sticky.AddHandler(name, handler)
 	}
 }
+
+func (b *Balancer) nextServer() (*namedHandler, error) {
+	b.handlersMu.Lock()
+	defer b.handlersMu.Unlock()
+
+	if len(b.handlers) == 0 || len(b.status) == 0 || len(b.fenced) == len(b.handlers) {
+		return nil, errNoAvailableServer
+	}
+
+	var handler *namedHandler
+	for {
+		// Pick handler with closest deadline.
+		handler = heap.Pop(b).(*namedHandler)
+
+		// curDeadline should be handler's deadline so that new added entry would have a fair competition environment with the old ones.
+		b.curDeadline = handler.deadline
+		handler.deadline += 1 / handler.weight
+
+		heap.Push(b, handler)
+		if _, ok := b.status[handler.name]; ok {
+			if _, ok := b.fenced[handler.name]; !ok {
+				// do not select a fenced handler.
+				break
+			}
+		}
+	}
+
+	log.Debug().Msgf("Service selected by WRR: %s", handler.name)
+	return handler, nil
+}
